@extends('app')

@section('breadcrumbs')
    {!!Breadcrumbs::render('home.reports')!!}
@endsection


@section('content')

<div class="container-fluid">
    <div class="row margin-y-20">
        <div class="col col-xs-6">
            @if($reports != null)
             {!!$reports->appends(request()->all())->render()!!}
            @endif
        </div>
        <div class="col-xs-6 text-right">
            {!!Form::open(['method' => 'get','id' => 'download-excel-form'])!!}
                {!!Form::hidden('excel','download')!!}
            
                <div class="btn-group">
                    <button id="filters-button" class="btn btn-default" data-toggle="modal" data-target="#filters-modal" type="button">
                        <span class="fa fa-fw fa-filter"></span> Filtros
                    </button>
                    <a class="btn btn-default" href="{{action('ReportRecordsController@index')}}"><span class="fa fa-fw fa-eraser"></span>Borrar filtros</a>
                    @if($reports != null && $reports->total() > 0 && $reports->total() < ReportRecord::MAX_EXPORT_LIMIT)
                        <button type="button" class="btn btn-default" id="report-request-button">
                            <span class="fa fa-fw fa-download"></span> Solicitar reporte
                        </button>
                    @elseif($reports->total() > ReportRecord::MAX_EXPORT_LIMIT)
                        <button type="button" class="btn btn-default disabled" data-toggle="tooltip" data-placement="bottom" title="Este reporte no puede exportarse porque es demasiado grande (Más de {{ReportRecord::MAX_EXPORT_DISPLAY}} registros). Limite su búsqueda con el uso de filtros">
                            <span class="fa fa-fw fa-download"></span> Solicitar reporte
                        </button>
                    @endif
                    
                </div>
            {!!Form::close()!!}
        </div>
    </div>
    
    @if($reports != null && $reports->count())
        <div class="table-responsive">
            <table class="table table-striped">
                <thead>
                    <tr>
                        <th>
                            Gerencia
                        </th>
                        <th>
                            No de empleado
                        </th>
                        <th>
                            Usuario
                        </th>
                        <th>
                            Cliente
                        </th>
                        <th>
                            Nombre de cliente
                        </th>
                        <th>
                            Estatus ACTUAL
                        </th>
                        <th>
                            Fecha
                        </th>
                        <th>
                            Acción
                        </th>
                        <th>
                            Descripción
                        </th>
                        <th>
                            Comentarios
                        </th>
                        <th>
                        </th>
                    </tr>
                </thead>
                <tbody>
                    @foreach($reports as $report)
                        <tr>
                            <th>
                                @if($m = $report->management)
                                    {{$m->name}}
                                @else
                                    -
                                @endif
                            </th>

                            <td>
                                {{$report->user->employee_number}}
                            </td>
                            <td>
                                {{$report->user->full_name}}
                            </td>
                            <td>
                                {{$report->client ? $report->client->cuenta : 'Sin cuenta'}}
                            </td>
                            <td>
                                {{$report->client ? ($report->client->nombre . " " . $report->client->paterno) : 'Sin Nombre' }}
                            </td>
                            <td>
                                {{ $report->client ? trans("clients.status.".$report->client->status) : null}}
                            </td>
                            <td class="datetime">
                                {{$report->created_at->format('d/m/Y H:i')}}
                            </td>
                            <td>
                                {{$report->action}}
                            </td>
                            <td>
                                {{$report->description}}
                            </td>
                            <td class="comments">
                                {{ $report->comments }}
                            </td>
                            <td>
                                <button class="btn-comments-modal btn btn-sm btn-primary" data-client-id="{{$report->client->id}}"><i class="fa fa-comment" aria-hidden="true"></i></button>
                            </td>
                        </tr>
                    @endforeach    
                </tbody>
                
            </table>
        </div>
    @else
        <div class="alert alert-info">
            No hay reportes que mostrar
        </div>
    @endif
</div>  

@endsection

@section('modals')
    @include('reports.modals.filters')
    @include('comments.modal')

@endsection

@section('script')
    @parent
    {!! Html::script('js/vendor/jquery/ui/core.min.js') !!}
    {!! Html::script('js/vendor/jquery/ui/widget.min.js') !!}
    {!! Html::script('js/vendor/jquery/ui/datepicker.min.js') !!}
    {!! Html::script('js/vendor/jquery.stickytableheaders.js') !!}
    {!! Html::script("js/moment/moment.js")!!}
    {!! Html::script('js/select2.full.js')!!}
    
    {!! Html::script('js/comments/index.js') !!}
    {!! Html::script('js/reports/index.js') !!}

@endsection

@section('style')
    @parent
    {!!Html::style('css/vendor/jquery-ui/thms/flick/jquery-ui.min.css') !!}
    {!!Html::style('css/vendor/jquery-ui/thms/flick/theme.css') !!}
    {!!Html::style('css/select2.css')!!}
    {!!Html::style('css/select2-bootstrap.css')!!}
    <style type="text/css">
        .ui-datepicker{
            z-index :3000 !important;
        }
    </style>
@endsection
